﻿using Infragistics.Controls.Editors;
using Infragistics.Themes;
using Infragistics.Windows.DataPresenter;
using System;
using System.Collections.Generic;
using System.Collections.ObjectModel;
using System.Linq;
using System.Text;
using System.Threading.Tasks;
using System.Windows;
using System.Windows.Controls;
using System.Windows.Data;
using System.Windows.Documents;
using System.Windows.Input;
using System.Windows.Media;
using System.Windows.Media.Imaging;
using System.Windows.Navigation;
using System.Windows.Shapes;

namespace XDGApplyThemeAtRuntime
{
    /// <summary>
    /// Interaction logic for MainWindow.xaml
    /// </summary>
    public partial class MainWindow : Window
    {
        public MainWindow()
        {
            InitializeComponent();
            this.xamDataGrid1.DataSource = CreateList();
            this.combo1.ItemsSource = CreateThemeList();
        }

        private ObservableCollection<Employee> CreateList()
        {
            return new ObservableCollection<Employee>()
                {
                   new Employee("John Smith", 5250.50, 20, new DateTime(2008,01,01)),
                   new Employee("Hania Dillard", 932874.22, 0, new DateTime(2012,03,17)),
                   new Employee("Devin Burgess", 6944.10, -10, new DateTime(2016,03,22)),
                   new Employee("Arisha Woodcock", 57449.10, 15, new DateTime(2018,11,09)),
                   new Employee("Celia Hogg", 123.50, -3, new DateTime(2011,09,11)),
                   new Employee("Payton Carr", 656749.50, 4, new DateTime(2014,12,26)),
                   new Employee("Angela Mclaughlin", 4894.50, 12, new DateTime(2005,06,30)),
                   new Employee("Ailsa Curtis", 5587.50, -23, new DateTime(2013,11,21)),
                   new Employee("Oscar Hubbard", 3745.50, -17, new DateTime(1986,09,29)),
                   new Employee("Naeem Hall", 54892.50, 10, new DateTime(1993,02,17)),
                   new Employee("Kaeden Vasquez", 56868.50, 3, new DateTime(1996,12,10)),
                   new Employee("Branden Gregory", 4974.50, -6, new DateTime(2017,12,10))
                };
        }

        private ObservableCollection<string> CreateThemeList()
        {
            return new ObservableCollection<string>()
            {
                "IGTheme",
                "MetroDarkTheme",
                "Office2013Theme"
            };
        }


        class Employee
        {
            public string Name { get; set; }
            public double Salary { get; set; }
            public double Score { get; set; }
            public DateTime StartDate { get; set; }

            public Employee(string name, double salary, int score, DateTime startDate)
            {
                Name = name;
                Salary = salary;
                Score = score;
                StartDate = startDate;
            }
        }

        private void combo1_DropDownClosed(object sender, EventArgs e)
        {
            if ((sender as XamComboEditor).SelectedItem == null) return;
            var selectedTheme = (sender as XamComboEditor).SelectedItem.ToString();
            switch (selectedTheme)
            {
                case "IGTheme":
                    ThemeManager.SetTheme(this.xamDataGrid1, new IgTheme());
                    break;
                case "MetroDarkTheme":
                    ThemeManager.SetTheme(this.xamDataGrid1, new MetroDarkTheme());
                    break;
                case "Office2013Theme":
                    ThemeManager.SetTheme(this.xamDataGrid1, new Office2013Theme());
                    break;
                default:
                    break;
            }

            var fieldSettings = this.xamDataGrid1.FieldLayouts[0].Fields[0].Settings;


            var currentLabelPresenterStyle = fieldSettings.LabelPresenterStyle as Style;
            var currentCVPStyle = fieldSettings.CellValuePresenterStyle as Style;

            var newLPStyle = new Style();
            newLPStyle.BasedOn = currentLabelPresenterStyle;
            newLPStyle.Setters.Add(new Setter(LabelPresenter.ForegroundProperty, Brushes.Red));
            newLPStyle.Setters.Add(new Setter(LabelPresenter.BackgroundProperty, Brushes.Yellow));
            Application.Current.Resources["customLabel"] = newLPStyle;

            var newCVPStyle = new Style();
            newCVPStyle.BasedOn = currentCVPStyle;
            newCVPStyle.Setters.Add(new Setter(CellValuePresenter.FontWeightProperty, FontWeights.Bold));
            Application.Current.Resources["customCVP"] = newCVPStyle;
        }
    }
}
